@@ -8,12 +8,18 @@
 /*
 /*	void	clean_env(preserve_list)
 /*	const char **preserve_list;
+/*
+/*	void	update_env(preserve_list)
+/*	const char **preserve_list;
 /* DESCRIPTION
 /*	clean_env() reduces the process environment to the bare minimum.
 /*	The function takes a null-terminated list of arguments.
 /*	Each argument specifies the name of an environment variable
 /*	that should be preserved, or specifies a name=value that should
 /*	be entered into the new environment.
+/*
+/*	update_env() applies name=value settings, but otherwise does not
+/*	change the process environment.
 /* DIAGNOSTICS
 /*	Fatal error: out of memory.
 /* SEE ALSO
@@ -85,3 +91,33 @@ void    clean_env(char **preserve_list)
      */
     argv_free(save_list);
 }
+
+/* update_env - apply name=value settings only */
+
+void    update_env(char **preserve_list)
+{
+    char  **cpp;
+    ARGV   *save_list;
+    char   *eq;
+
+    /*
+     * Extract name=value settings.
+     */
+    save_list = argv_alloc(10);
+    for (cpp = preserve_list; *cpp; cpp++)
+	if ((eq = strchr(*cpp, '=')) != 0)
+	    argv_addn(save_list, STRING_AND_LENGTH(*cpp, eq - *cpp),
+		      STRING_AND_LENGTH(eq + 1, strlen(eq + 1)), (char *) 0);
+
+    /*
+     * Apply name=value settings.
+     */
+    for (cpp = save_list->argv; *cpp; cpp += 2)
+	if (setenv(cpp[0], cpp[1], 1))
+	    msg_fatal("setenv(%s, %s): %m", cpp[0], cpp[1]);
+
+    /*
+     * Cleanup.
+     */
+    argv_free(save_list);
+}
